[Qa-jenkins-scm] [jenkins.debian.net] 01/01: reproducible: add 4 more amd64 builder jobs and 2 more armhf

Holger Levsen holger at moszumanska.debian.org
Fri Sep 18 22:53:24 UTC 2015


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit 2621a5b3a9b0682d908e52badb314fc4a79af9b0
Author: Holger Levsen <holger at layer-acht.org>
Date:   Sat Sep 19 00:53:12 2015 +0200

    reproducible: add 4 more amd64 builder jobs and 2 more armhf
---
 bin/reproducible_html_live_status.py |  4 +--
 job-cfg/reproducible.yaml            | 60 ++++++++++++++++++++++++++++++++++++
 2 files changed, 62 insertions(+), 2 deletions(-)

diff --git a/job-cfg/reproducible.yaml b/job-cfg/reproducible.yaml
index ed72caa..d244ebd 100644
--- a/job-cfg/reproducible.yaml
+++ b/job-cfg/reproducible.yaml
@@ -402,6 +402,22 @@
 
 - job-template:
     defaults: reproducible_builder
+    name: '{name}_builder_amd64_13'
+
+- job-template:
+    defaults: reproducible_builder
+    name: '{name}_builder_amd64_14'
+
+- job-template:
+    defaults: reproducible_builder
+    name: '{name}_builder_amd64_15'
+
+- job-template:
+    defaults: reproducible_builder
+    name: '{name}_builder_amd64_16'
+
+- job-template:
+    defaults: reproducible_builder
     name: '{name}_builder_armhf_1'
 
 - job-template:
@@ -425,6 +441,14 @@
     name: '{name}_builder_armhf_6'
 
 - job-template:
+    defaults: reproducible_builder
+    name: '{name}_builder_armhf_7'
+
+- job-template:
+    defaults: reproducible_builder
+    name: '{name}_builder_armhf_8'
+
+- job-template:
     defaults: reproducible_other_projects
     name: '{name}_coreboot'
 
@@ -818,6 +842,30 @@
             my_shell: '/srv/jenkins/bin/reproducible_build.sh profitbricks-build2-amd64 profitbricks-build1-amd64'
             my_recipients: 'qa-jenkins-scm at lists.alioth.debian.org'
             my_node: ''
+        - '{name}_builder_amd64_13':
+            my_description: 'Try to reproducibly build a scheduled package. This is one of several builder jobs.'
+            my_timed: '* * * * *'
+            my_shell: '/srv/jenkins/bin/reproducible_build.sh profitbricks-build1-amd64 profitbricks-build2-amd64'
+            my_recipients: 'qa-jenkins-scm at lists.alioth.debian.org'
+            my_node: ''
+        - '{name}_builder_amd64_14':
+            my_description: 'Try to reproducibly build a scheduled package. This is one of several builder jobs.'
+            my_timed: '* * * * *'
+            my_shell: '/srv/jenkins/bin/reproducible_build.sh profitbricks-build2-amd64 profitbricks-build1-amd64'
+            my_recipients: 'qa-jenkins-scm at lists.alioth.debian.org'
+            my_node: ''
+        - '{name}_builder_amd64_15':
+            my_description: 'Try to reproducibly build a scheduled package. This is one of several builder jobs.'
+            my_timed: '* * * * *'
+            my_shell: '/srv/jenkins/bin/reproducible_build.sh profitbricks-build1-amd64 profitbricks-build2-amd64'
+            my_recipients: 'qa-jenkins-scm at lists.alioth.debian.org'
+            my_node: ''
+        - '{name}_builder_amd64_16':
+            my_description: 'Try to reproducibly build a scheduled package. This is one of several builder jobs.'
+            my_timed: '* * * * *'
+            my_shell: '/srv/jenkins/bin/reproducible_build.sh profitbricks-build2-amd64 profitbricks-build1-amd64'
+            my_recipients: 'qa-jenkins-scm at lists.alioth.debian.org'
+            my_node: ''
         - '{name}_builder_armhf_1':
             my_description: 'Try to reproducibly build a scheduled package. This is one of several builder jobs.'
             my_timed: '* * * * *'
@@ -854,6 +902,18 @@
             my_shell: '/srv/jenkins/bin/reproducible_build.sh wbq0-armhf-rb:2225 hb0-armhf-rb:2224'
             my_recipients: 'qa-jenkins-scm at lists.alioth.debian.org'
             my_node: ''
+        - '{name}_builder_armhf_7':
+            my_description: 'Try to reproducibly build a scheduled package. This is one of several builder jobs.'
+            my_timed: '* * * * *'
+            my_shell: '/srv/jenkins/bin/reproducible_build.sh wbq0-armhf-rb:2225 bpi0-armhf-rb:2222'
+            my_recipients: 'qa-jenkins-scm at lists.alioth.debian.org'
+            my_node: ''
+        - '{name}_builder_armhf_8':
+            my_description: 'Try to reproducibly build a scheduled package. This is one of several builder jobs.'
+            my_timed: '* * * * *'
+            my_shell: '/srv/jenkins/bin/reproducible_build.sh cbxi4pro0-armhf-rb:2226 hb0-armhf-rb:2224'
+            my_recipients: 'qa-jenkins-scm at lists.alioth.debian.org'
+            my_node: ''
         - '{name}_coreboot':
             my_description: 'Rebuild all coreboot ROMs twice (with variations) and investigate regarding reproducibility.'
             my_timed: '23 42 * * 1'

diff --git a/bin/reproducible_html_live_status.py b/bin/reproducible_html_live_status.py
index fdd9a87..334a31b 100755
--- a/bin/reproducible_html_live_status.py
+++ b/bin/reproducible_html_live_status.py
@@ -76,8 +76,8 @@ def generate_live_status_table(arch):
     counter = 0
     for row in rows:
         counter += 1
-        # the numbers 13 and 7 should really be derived from /var/lib/jenkins/jobs/reproducible_builder_${arch}_* instead of being hard-coded here...
-        if ( arch == 'amd64' and counter == 13 ) or ( arch == 'armhf' and counter == 7 ):
+        # the numbers 17 and 9 should really be derived from /var/lib/jenkins/jobs/reproducible_builder_${arch}_* instead of being hard-coded here...
+        if ( arch == 'amd64' and counter == 17 ) or ( arch == 'armhf' and counter == 9 ):
              html += '<tr><td colspan="10">There are more builds marked as currently building in the database than there are ' + arch + ' build jobs. This does not compute. Please cleanup and please automate cleanup.</td></tr>'
         suite = row[1]
         arch = row[2]
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list